==> InfiniTec.Exchange_0.96_Source.zip: CompleteName.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information about a name of a person.
    /// </summary>
    public class CompleteName
    {
        private TypedItemBase _Item;

        /// <summary>
        /// Initializes a new instance of the <see cref="CompleteName"/> class.
        /// </summary>
        /// <param name="item">The item.</param>
        public CompleteName(TypedItemBase item)
        {
            _Item = item;
        }

        /// <summary>
        /// Returns or sets a String indicating the Japanese phonetic rendering (yomigana) of the last name for the contact.
        /// </summary>
        /// <value>The name of the yomi last.</value>
        public string YomiLastName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.YomiLastName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.YomiLastName, value); }
        }

        /// <summary>
        /// Returns or sets a String indicating the Japanese phonetic rendering (yomigana) of the first name for the contact
        /// </summary>
        /// <value>The name of the yomi first.</value>
        public string YomiFirstName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.YomiFirstName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.YomiFirstName, value); }
        }

        /// <summary>
        /// Gets or sets the nickname.
        /// </summary>
        /// <value>The name of the nick.</value>
        public string NickName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.NickName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.NickName, value); }

        }

        /// <summary>
        /// Gets or sets the full name.
        /// </summary>
        /// <value>The full name.</value>
        public string FullName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.DisplayName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.DisplayName, value); }
        }

        /// <summary>
        /// Gets or sets the initials.
        /// </summary>
        /// <value>The initials.</value>
        public string Initials
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Initials); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Initials, value); }
        }

        /// <summary>
        /// Gets or sets the suffix.
        /// </summary>
        /// <value>The suffix.</value>
        public string Suffix
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Generation); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Generation, value); }
        }

        /// <summary>
        /// Gets or sets the last name
        /// </summary>
        /// <value>The last name.</value>
        public string LastName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Surname); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Surname, value); }
        }

        /// <summary>
        /// Gets or sets the middle name
        /// </summary>
        /// <value>The middle name.</value>
        public string MiddleName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.MiddleName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.MiddleName, value); }
        }

        /// <summary>
        /// Gets or sets the first name
        /// </summary>
        /// <value>The first name</value>
	    public string FirstName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.GivenName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.GivenName, value); }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Prefix); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Prefix, value); }
        }
    }
}

==> InfiniTec.Exchange_0.97_Source.zip: CompleteName.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class contains information about a name of a person.
    /// </summary>
    public class CompleteName
    {
        private Item _Item;

        /// <summary>
        /// Initializes a new instance of the <see cref="CompleteName"/> class.
        /// </summary>
        /// <param name="item">The item.</param>
        public CompleteName(Item item)
        {
            _Item = item;
        }

        /// <summary>
        /// Returns or sets a String indicating the Japanese phonetic rendering (yomigana) of the last name for the contact.
        /// </summary>
        /// <value>The name of the yomi last.</value>
        public string YomiLastName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.YomiLastName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.YomiLastName, value); }
        }

        /// <summary>
        /// Returns or sets a String indicating the Japanese phonetic rendering (yomigana) of the first name for the contact
        /// </summary>
        /// <value>The name of the yomi first.</value>
        public string YomiFirstName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.YomiFirstName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.YomiFirstName, value); }
        }

        /// <summary>
        /// Gets or sets the nickname.
        /// </summary>
        /// <value>The name of the nick.</value>
        public string NickName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.NickName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.NickName, value); }

        }

        /// <summary>
        /// Gets or sets the full name.
        /// </summary>
        /// <value>The full name.</value>
        public string FullName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.DisplayName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.DisplayName, value); }
        }

        /// <summary>
        /// Gets or sets the initials.
        /// </summary>
        /// <value>The initials.</value>
        public string Initials
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Initials); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Initials, value); }
        }

        /// <summary>
        /// Gets or sets the suffix.
        /// </summary>
        /// <value>The suffix.</value>
        public string Suffix
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Generation); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Generation, value); }
        }

        /// <summary>
        /// Gets or sets the last name
        /// </summary>
        /// <value>The last name.</value>
        public string LastName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Surname); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Surname, value); }
        }

        /// <summary>
        /// Gets or sets the middle name
        /// </summary>
        /// <value>The middle name.</value>
        public string MiddleName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.MiddleName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.MiddleName, value); }
        }

        /// <summary>
        /// Gets or sets the first name
        /// </summary>
        /// <value>The first name</value>
	    public string FirstName
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.GivenName); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.GivenName, value); }
        }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get { return _Item.GetPropertyValue<string>(NamedProperties.Contact.Prefix); }
            set { _Item.SetPropertyValue<string>(NamedProperties.Contact.Prefix, value); }
        }
    }
}
